@@ -1,6 +1,8 @@
 from .enums import StreamState, StreamType  # noqa
+from .errors import (InvalidMinimumApproachTempDiffError, InvalidStreamError,
+                     PyHeatIntegrationError)
 from .grand_composite_curve import GrandCompositeCurve  # noqa
 from .line import convert_to_excel_data, extract_x, y_range  # noqa
 from .pinch_analyzer import PinchAnalyzer  # noqa
-from .stream import Stream  # noqa
+from .streams import Stream  # noqa
 from .tq_diagram import TQDiagram, get_possible_minimum_temp_diff_range  # noqa
